"""Balance plugin

Extends users plugin with balance functions
"""

from werkzeug.local import LocalProxy
from flask import Blueprint, current_app

from flaschengeist import logger
from flaschengeist.plugins import Plugin, before_update_user

from . import permissions, models


class BalancePlugin(Plugin):
    name = "balance"
    blueprint = Blueprint(name, __name__)
    permissions = permissions.permissions
    plugin = LocalProxy(lambda: current_app.config["FG_PLUGINS"][BalancePlugin.name])
    models = models

    def __init__(self, config):
        super(BalancePlugin, self).__init__(config)
        from . import routes, balance_controller

        @before_update_user
        def set_default_limit(user):
            try:
                limit = self.get_setting("limit")
                logger.debug("Setting default limit of {} to user {}".format(limit, user.userid))
                balance_controller.set_limit(user, limit, override=False)
            except KeyError:
                pass
